@@ -6,11 +6,12 @@ class Dropout(Module):
         super().__init__()
     def forward(self, X):
         import neurograd as ng
-        from neurograd import xp
+        from neurograd import xp, Tensor
         if self.training:
             keep_prob = 1 - self.dropout_rate
-            mask = xp.random.rand(*X.shape) < keep_prob
-            X = X * mask / keep_prob
+            mask = (xp.random.rand(*X.shape) < keep_prob) / keep_prob
+            mask = Tensor(mask, requires_grad=False)
+            X = X * mask
         return X
     
 
@@ -20,11 +21,12 @@ class Dropout2D(Module):
         super().__init__()
     def forward(self, X):
         import neurograd as ng
-        from neurograd import xp
+        from neurograd import xp, Tensor
         if self.training:
             keep_prob = 1 - self.dropout_rate
             # For NCHW format: (N, C, H, W), apply dropout per channel
-            mask = xp.random.rand(X.shape[0], X.shape[1], 1, 1) < keep_prob
-            X = X * mask / keep_prob
+            mask = (xp.random.rand(X.shape[0], X.shape[1], 1, 1) < keep_prob) / keep_prob
+            mask = Tensor(mask, requires_grad=False)
+            X = X * mask
         return X
 
