@@ -10,18 +10,19 @@ else:
     from cupy import fuse
     conditional_fuse = fuse
 
-
 @conditional_fuse
-def fused_adam_step(param, grad, m, v, lr, beta1, beta2, epsilon, t):
-    # Update biased first and second moment estimates
-    m[:] = beta1 * m + (1 - beta1) * grad
-    v[:] = beta2 * v + (1 - beta2) * grad * grad
-    # Compute bias-corrected moments
-    m_hat = m / (1 - beta1 ** t)
-    v_hat = v / (1 - beta2 ** t)
-    # Parameter update
-    param[:] -= lr * m_hat / (xp.sqrt(v_hat) + epsilon)
-    return param
+def fused_update_momentum(m, grad, beta1):
+    # m = beta1 * m + (1 - beta1) * grad
+    return beta1 * m + (1 - beta1) * grad
+@conditional_fuse
+def fused_update_variance(v, grad, beta2):
+    # v = beta2 * v + (1 - beta2) * grad^2
+    return beta2 * v + (1 - beta2) * grad * grad
+@conditional_fuse
+def fused_param_update(param, m, v, lr_corrected, bias2, epsilon):
+    # param -= lr_corrected * m / (sqrt(v / bias2) + epsilon)
+    denom = xp.sqrt(v / bias2) + epsilon
+    return param - lr_corrected * m / denom
 
 
 
@@ -51,30 +52,39 @@ class Adam(Optimizer):
         self.beta1 = beta1
         self.beta2 = beta2
         self.epsilon = epsilon
-        self.t = 0
+        self.t = 1
 
 
     def step(self) -> None:
         self.t += 1
+        bias1 = 1 - self.beta1 ** self.t
+        bias2 = 1 - self.beta2 ** self.t
+        lr_corrected = self.lr / bias1
+        
         for i, (name, param) in enumerate(self.params):
             if param.requires_grad and param.grad is not None:
+                grad = param.grad
                 m = self.first_momentum[i][1]
                 v = self.second_momentum[i][1]
-                # Weight decay before momentum updates
+                
+                # Weight decay fused with grad (in-place)
                 if self.weight_decay > 0:
-                    xp.add(param.grad, self.weight_decay * param.data, out=param.grad)
-                # Update moments and parameters
-                param.data = fused_adam_step(param.data, param.grad, m, v, self.lr,
-                                             self.beta1, self.beta2, self.epsilon, self.t)
-
+                    xp.add(grad, self.weight_decay * param.data, out=grad)
+                
+                # Fused momentum update
+                m[:] = fused_update_momentum(m, grad, self.beta1)
+                # Fused variance update
+                v[:] = fused_update_variance(v, grad, self.beta2)
+                # Fused parameter update
+                param.data[:] = fused_param_update(param.data, m, v, lr_corrected, bias2, self.epsilon)
     
+
     def state_dict(self) -> dict:
         return {
             "lr": self.lr,
             "beta1": self.beta1,
             "beta2": self.beta2,
             "epsilon": self.epsilon,
-            "weight_decay": self.weight_decay,
             "params": self.params,
             "first_momentum": self.first_momentum,
             "second_momentum": self.second_momentum
@@ -85,7 +95,6 @@ class Adam(Optimizer):
         self.beta1 = state_dict["beta1"]
         self.beta2 = state_dict["beta2"]
         self.epsilon = state_dict["epsilon"]
-        self.weight_decay = state_dict["weight_decay"]
         self.params = state_dict["params"]
         self.first_momentum = state_dict["first_momentum"]
         self.second_momentum = state_dict["second_momentum"]
@@ -94,4 +103,4 @@ class Adam(Optimizer):
         return f"Adam(lr={self.lr}, beta1={self.beta1}, beta2={self.beta2}, epsilon={self.epsilon}, weight_decay={self.weight_decay})."
 
     def __str__(self) -> str:
-        return f"Adam with learning rate {self.lr}, beta1 {self.beta1}, beta2 {self.beta2}, epsilon {self.epsilon}, and weight decay {self.weight_decay}."
+        return f"Adam with learning rate {self.lr}, beta1 {self.beta1}, beta2 {self.beta2}, epsilon {self.epsilon}, and weight decay {self.weight_decay}."
\ No newline at end of file
