@@ -172,7 +172,7 @@ class ImageFolder(Dataset):
 
             # Stack with NumPy; Tensor handles xp conversion
             X = Tensor(np.stack(images, axis=0), dtype=self.img_dtype)
-            y = Tensor(np.asarray(targets), dtype=self.target_dtype)
+            y = Tensor(targets, dtype=self.target_dtype)
             return X, y
 
         # Single index path
